# CLEAR ====
#
rm(list = ls()) # clear memory
graphics.off()  # clear all plots
cat("\014")     # clear console (same as Ctrl-L in console)
library(readr)
# SET WORKING DIRECTORY ====
wd = paste('C:','Users',Sys.getenv("USERNAME"),'Box Sync','AAN4', 'figshare',sep = '/')
# Make functions ====
# Confidence interaval
ci = function(data){return(t.test(data)$conf.int[1:2])}
# format float with 1 decimal
form = function(x,n){return(format(round(x,n),nsmall = n))}
# Bayes factor function
# Point to BF_U.R file
source(paste(wd,'R', 'bayesfactor', 'BF_U.R', sep = '/'))
BF = function(data, LL = -1, UL = 1, plot = 0){
  meanobtained = mean(data)
  semobtained = sd(data)/sqrt(length(data))
  dfobtained = length(data)-1
  bf = BF_U(LL, UL, meanobtained, semobtained, dfobtained)
  # if (plot == 0){
  #   graphics.off()
  # }
  return(bf)
}

# READ LOGFILES ADD VARIABLES ====
# Point to log folder
logfolder = paste('data','log',sep = '/')

setwd(paste(wd, logfolder, sep = '/'))

path = getwd()
# list of folders with "fp"
folder = dir(pattern = 'fp')
df = data.frame()
cal = data.frame(cal = rep(0,length(folder)))
for (fps in 1:length(folder)){
  setwd(paste(path,sprintf('fp%02d',fps),sep = '/')) # enter current fp
  fp = dir(pattern = 'fp')
  cal$cal[fps] = length(dir(pattern = 'cal'))
  cal$val[fps] = length(dir(pattern = 'val'))
  tmp = read_delim(fp, "\t", escape_double = FALSE, trim_ws = TRUE, skip = 6)
  #create extra variables
  tmp$unaware = 1
  tmp$unaware[tmp$aware==1] = 0
  tmp$type = 0
  tmp$type[tmp$cond == 0] = "critical"
  tmp$type[tmp$cond == 1] = "control"
  tmp$type[tmp$cond == 2] = "catch"
  df=rbind(tmp,df)
  
  setwd('..')
}
rm(fp,fps,logfolder,tmp,path)

# AGGREGATE VARIABLES
#
d=data.frame()
# fp = 1
for (fp in folder){
  fp = as.integer(substr(fp,3,nchar(fp)))
  tdf = df[df$fp == fp,]
  #Add subject number
  tmp=data.frame(fp)
  #Number of trials rated as aware or unaware for response and non-response conds
  # Critical trials (max 480) Control trials (max 60) Catch trials (max 60)
  tmp$Ar = sum(tdf$aware[tdf$type=='critical' & tdf$gonogo==1])
  tmp$Ur = sum(tdf$unaware[tdf$type=='critical' & tdf$gonogo==0])
  tmp$Ctrl_r = sum(tdf$aware[tdf$type=='control' & tdf$gonogo==1])
  tmp$Catch_r = sum(tdf$aware[tdf$type=='catch' & tdf$gonogo==1])
  tmp$An = sum(tdf$aware[tdf$type=='critical' & tdf$gonogo==0])
  tmp$Un = sum(tdf$unaware[tdf$type=='critical' & tdf$gonogo==1])
  tmp$Ctrl_n = sum(tdf$aware[tdf$type=='control' & tdf$gonogo==0])
  tmp$Catch_n = sum(tdf$aware[tdf$type=='catch' & tdf$gonogo==0])
  # Reaction times critical trials
  tmp$RT_A_crit = mean(as.double(tdf$RT[tdf$pressed==1 & tdf$gonogo==1 & tdf$type=='critical']))*1e3
  tmp$RT_U_crit = mean(as.double(tdf$RT[tdf$pressed==1 & tdf$gonogo==0 & tdf$type=='critical']))*1e3
  # Reaction times control trials
  tmp$RT_A_cont = mean(as.double(tdf$RT[tdf$pressed==1 & tdf$gonogo==1 & tdf$type=='control']))*1e3
  # Reaction times catch trials
  tmp$RT_U_catch = mean(as.double(tdf$RT[tdf$pressed==1 & tdf$gonogo==0 & tdf$type=='catch']))*1e3
  # Tone levels
  tmp$levelcrit = mean(tdf$level[tdf$type=='critical'])
  tmp$levelcontrol = mean(tdf$level[tdf$type=='control'])
  tmp$aware = (tmp$Ar+tmp$An)/480
  #-----------------------------------------------------------------------------
  d=rbind(d,tmp)
  rm(tmp)
}
d=cbind(d, cal)
rm(tdf,fp,cal,folder)

# EXCLUDE ====
d = d[!d$fp %in% c(50),] # 50 stopped after half the experiment

# ADD AGE, SEX, AND HAND ====
sexagefile = paste('data','ParticipantsAAN4.csv',sep = '/')
sexAge =  read_csv(paste(wd,sexagefile,sep = '/'))
d <- merge(d,sexAge,by="fp", all = F)
rm(sexAge, sexagefile)
# Load EEG data ====
# Select data file
datafile = 'AAN4_amps_preregistered.csv'
#datafile = 'AAN4_amps_data_driven.csv'
a = read.csv(paste(wd,'results', datafile, sep = '/'), sep=",",header=T, dec=".")
# 2.1. Participants ====
#     #Demographics ====
ma = sum(d$`Sex (m=1)`)
h = sum(d$Hand)
m = form(mean(d$Age),1)
sd = form(sd(d$Age),1)
paste('(age: M = ',m, ' years, SD = ',sd,'), of whom ',ma, ' were male and ', h, ' were right-handed.',sep = '')
rm(ma, h, m, sd)

# 2.3. Procedure ====
#     #Number of validations ====
n = max(d$val)
m = form(mean(d$val),2)
sd = form(sd(d$val),2)

paste('M = ', m, ' (SD = ', sd, ')', sep = '')
paste('(max = ',n,')',sep = '')
rm(n, m, sd)

# 3.1. Behavior
#     #Table 1 (Behavior) ====
dr = cbind(d[2:3]/2.4, d[4:5]/.3)
dn = cbind(d[6:7]/2.4, d[8:9]/.3)
diff = dr-dn
table1 = data.frame(m = apply(dr,2,mean),
                    sd = apply(dr,2,sd),
                    m = apply(dn,2,mean),
                    sd = apply(dn,2,sd),
                    m = apply(diff,2,mean),
                    ll = apply(diff,2,ci)[1,],
                    ul = apply(diff,2,ci)[2,])
rownames(table1) = c('Critical: Aware (%)',
                     'Critical: Unaware (%)',
                     'Control: Aware (%)',
                     'Catch: Aware (%)')
colnames(table1) = c('Mean', 'SD', 'Mean', 'SD', 'Diff', 'LL', 'UL')
table1 = round(table1, 1)
rm(dr, dn, diff)
#     #Reaction times ====
# RT unaware
m = form(mean(d$RT_U_crit),0)
sd = form(sd(d$RT_U_crit),0)
paste(m,' ms (SD = ',sd,')')
# RT aware
m = form(mean(d$RT_A_crit),0)
sd = form(sd(d$RT_A_crit),0)
paste(m,' ms (SD = ',sd,')')

m = form(mean(d$RT_U_crit-d$RT_A_crit),0)
ll = form(ci(d$RT_U_crit-d$RT_A_crit)[1],0)
ul = form(ci(d$RT_U_crit-d$RT_A_crit)[2],0)
paste('difference = ', m, ', 95% CI [',ll,', ',ul,']',sep = '')

rm(m, sd, ll, ul)
#     # Sound pressure level (dB conversion) ====
# critical tone level
m = form(83.6 - abs(mean(d$levelcrit)),0)
sd = form(sd(d$levelcrit),0)
paste(m,' dB (SD = ',sd,')',sep = '')
rm(m, sd)
# 3.2. Auditory awareness negativity: ERP
#     #Table 2 (Mean amplitudes AAN/LP) ====
t = cbind(a[14:15], a[14]-a[15],a[16:17], a[16]-a[17], a[22:23], a[22]-a[23])
colnames(t) = c('AANr', 'AANn', 'AANrmn', 'LPr', 'LPn', 'LPrmn', 
                'LPexpr', 'LPexpn', 'LPexprmn')
# Sum aan, lp
n = nrow(a)
table2 = data.frame(rep(n, ncol(t)))
table2$MeanMv = apply(t,2,mean)
table2$SD = apply(t,2,sd)
table2$CIL = apply(t,2,ci)[1,]
table2$CIU = apply(t,2,ci)[2,]
table2$BF01 = 1/apply(t,2,BF)
table2$BF10 = apply(t,2,BF)

table2[,6:7][table2[,6:7] < 0.01] = 0.01
table2 = round(table2,2)

colnames(table2) = c('N', 'Mean (V)','SD' ,'95% CI','CI+', 'BF01', 'BF10')
rownames(table2) = c('AAN Response', 'AAN No-response', 
                     'AAN Response - No-response', 
                     'LP Response', 'LP No-response',
                     'LP Response - No-response',
                     'LP Response (350-450 ms)', 'LP No-response (350-450 ms)',
                     'LP Response - No-response (350-450 ms)')

rm(t)
# 4. Discussion ====
#     #Mean response difference AAN ====
m = form(mean(a$AANr-a$AANn),2)
ll = form(ci(a$AANr-a$AANn)[1],2)
ul = form(ci(a$AANr-a$AANn)[2],2)
paste(m,' V, 95% CI [',ll,', ',ul,']',sep = '')
#     #Mean response difference LP ====
m = form(mean(a$LPr-a$LPn),2)
ll = form(ci(a$LPr-a$LPn)[1],2)
ul = form(ci(a$LPr-a$LPn)[2],2)
paste(m,' V, 95% CI [',ll,', ',ul,']',sep = '')
# PLOTS ====
# Plot percent aware for all subjects ====
#
plot(d$hit/480,ylim = c(0,1),main = round(mean(d$hit/480*100),2),xlab = 'FP', ylab = 'Percent aware')
abline(0.5,0)
abline(mean(d$hit)/480,0, lty = 3, col = 'red')

# Check awareness level per block ====
par(mfrow=c(4,4), pty='m')
# plot all subjects aware level over blocks
for (fp in d$fp){
  tdf = df[df$fp==fp,]
  plot(table(tdf$aware[tdf$type=='critical'], tdf$block[tdf$type=='critical'])[2,]/80, ylim = c(0,80)/80,
       main = bquote(expr = 'fp =' ~ .(fp) ~ ', Aware = ' ~ .(round(mean(tdf$aware[tdf$type=='critical'])*100,2))~'%'), 
       xlab = 'Block', ylab = 'Nr critical trials aware out of 80', 
       pch = 21, col = 'black', bg = 'red', cex = 1)
  #points(control[2,]/10, pch = 22, col = 'black', bg = 'green', cex = 0.8)
  #points(catch[1,]/10, pch = 22, col = 'black', bg = 'blue', cex = 0.8)
  abline(a = 0.5,b = 0) # 50 % aware line
  abline(a = mean(tdf$aware[tdf$type=='critical']), b = 0, lty = 3, col = 'red')
  abline(a = mean(tdf$aware[tdf$type=='control']), b = 0, lty = 4, col = 'green')
  abline(a = mean(tdf$aware[tdf$type=='catch']), b = 0, lty = 4, col = 'blue')}
rm(fp)

# Plot reaction times ====
par(mfrow=c(3,3))
PlotRT = function(fp){
  tdf = df[df$fp==fp,]
  plot(x = tdf$trial[tdf$pressed==1 & tdf$gonogo==1 & tdf$RT > 0],
       tdf$RT[tdf$pressed==1 & tdf$gonogo==1 & tdf$RT > 0], col = 'blue',
       xlim = c(1,600), ylim = c(0,3), xlab = 'Trial', ylab = 'RT', main = fp)
  points(x = tdf$trial[tdf$pressed==1 & tdf$gonogo==0 & tdf$RT > 0],
         tdf$RT[tdf$pressed==1 & tdf$gonogo==0 & tdf$RT > 0], col = 'red')
  abline(v = seq(0,600,100))}

for (fp in 1:max(d$fp)){
  PlotRT(fp)}
rm(fp)


